@@ -244,9 +244,6 @@ MessageName(winWMMessagePtr msg)
     case WM_WM_CHANGE_STATE:
       return "WM_WM_CHANGE_STATE";
       break;
-    case WM_WM_MAP:
-      return "WM_WM_MAP";
-      break;
     case WM_WM_MAP_UNMANAGED:
       return "WM_WM_MAP_UNMANAGED";
       break;
@@ -994,6 +991,13 @@ winMultiWindowWMProc(void *pArg)
             /* Determine the Window style, which determines borders and clipping region... */
             UpdateStyle(pWMInfo, pNode->msg.iWindow, &maxmin);
 
+            /* Make sure it gets the proper system menu for a WS_POPUP, too */
+            GetSystemMenu(pNode->msg.hwndWindow, TRUE);
+
+#define WM_INIT_SYS_MENU	(WM_USER + 1001)
+            /* Cause any .XWinrc menus to be added in main WNDPROC */
+            PostMessage(pNode->msg.hwndWindow, WM_INIT_SYS_MENU, 0, 0);
+
             /* Display the window without activating it */
             {
                 xcb_get_window_attributes_cookie_t cookie;
@@ -1057,11 +1061,6 @@ winMultiWindowWMProc(void *pArg)
             }
             break;
 
-        case WM_WM_MAP:
-            UpdateName(pWMInfo, pNode->msg.iWindow);
-            UpdateIcon(pWMInfo, pNode->msg.iWindow);
-            break;
-
         case WM_WM_MAP_UNMANAGED:
             break;
 
